@@ -1,4 +1,3 @@
-import ctypes
 import json
 import os
 import queue
@@ -13,7 +12,9 @@ from koapy.backend.kiwoom_open_api_plus.core.KiwoomOpenApiPlusError import (
 from koapy.backend.kiwoom_open_api_plus.core.KiwoomOpenApiPlusRateLimiter import (
     KiwoomOpenApiPlusCommRqDataRateLimiter,
     KiwoomOpenApiPlusSendConditionRateLimiter,
+    KiwoomOpenApiPlusSendOrderRateLimiter,
 )
+from koapy.utils.ctypes import is_admin
 from koapy.utils.logging.Logging import Logging
 from koapy.utils.subprocess import function_to_subprocess_args
 
@@ -136,10 +137,10 @@ class KiwoomOpenApiPlusSimpleQAxWidgetMixin:
         return "감리종목" in self.GetMasterStockStateAsList(code)
 
     def GetConditionFilePath(self):
-        modulepath = self.GetAPIModulePath()
+        module_path = self.GetAPIModulePath()
         userid = self.GetUserId()
         condition_filepath = os.path.join(
-            modulepath, "system", "%s_NewSaveIndex.dat" % userid
+            module_path, "system", "%s_NewSaveIndex.dat" % userid
         )
         return condition_filepath
 
@@ -158,12 +159,10 @@ class KiwoomOpenApiPlusComplexQAxWidgetMixin(Logging):
         self._cond_rate_limiter = KiwoomOpenApiPlusSendConditionRateLimiter(
             self._comm_rate_limiter
         )
+        self._send_order_limiter = KiwoomOpenApiPlusSendOrderRateLimiter()
 
         self._is_condition_loaded = False
 
-    def IsAdmin(self):
-        return ctypes.windll.shell32.IsUserAnAdmin() != 0
-
     def DisableAutoLogin(self):
         module_path = self.GetAPIModulePath()
         autologin_dat = os.path.join(module_path, "system", "Autologin.dat")
@@ -277,7 +276,7 @@ class KiwoomOpenApiPlusComplexQAxWidgetMixin(Logging):
     def Connect(self, credential=None):
         if credential is not None:
             assert (
-                self.IsAdmin()
+                is_admin()
             ), "Connect() method requires to be run as administrator, if credential is given explicitly"
         q = queue.Queue()
 
@@ -388,7 +387,7 @@ class KiwoomOpenApiPlusComplexQAxWidgetMixin(Logging):
         [조건검색 제한]
           조건검색(실시간 조건검색 포함)은 시세조회와 관심종목조회와 합산해서 1초에 5회만 요청 가능하며 1분에 1회로 조건검색 제한됩니다.
         """
-        self._comm_rate_limiter.sleep_if_necessary()
+        self._cond_rate_limiter.sleep_if_necessary()
         return self.CommKwRqData(codes, prevnext, codecnt, typeflag, rqname, scrnno)
 
     def RateLimitedCommRqDataAndCheck(
@@ -396,7 +395,9 @@ class KiwoomOpenApiPlusComplexQAxWidgetMixin(Logging):
     ):
         code = self.RateLimitedCommRqData(rqname, trcode, prevnext, scrnno)
 
-        spec = "CommRqData(%r, %r, %r, %r)" % (rqname, trcode, prevnext, scrnno)
+        spec = "CommRqData({!r}, {!r}, {!r}, {!r})".format(
+            rqname, trcode, prevnext, scrnno
+        )
 
         if inputs is not None:
             spec += " with inputs %r" % inputs
@@ -434,10 +435,10 @@ class KiwoomOpenApiPlusComplexQAxWidgetMixin(Logging):
 
         return code
 
-    def RatedLimitedSendOrder(
+    def RateLimitedSendOrder(
         self, rqname, scrnno, accno, ordertype, code, qty, price, hogagb, orgorderno
     ):
-        self._comm_rate_limiter.sleep_if_necessary()
+        self._send_order_limiter.sleep_if_necessary()
         return self.SendOrder(
             rqname, scrnno, accno, ordertype, code, qty, price, hogagb, orgorderno
         )
@@ -454,7 +455,7 @@ class KiwoomOpenApiPlusComplexQAxWidgetMixin(Logging):
         [조건검색 제한]
           조건검색(실시간 조건검색 포함)은 시세조회와 관심종목조회와 합산해서 1초에 5회만 요청 가능하며 1분에 1회로 조건검색 제한됩니다.
         """
-        self._cond_rate_limiter.sleep_if_necessary()
+        self._cond_rate_limiter.sleep_if_necessary(condition_name, condition_index)
         return self.SendCondition(scrnno, condition_name, condition_index, search_type)
 
 
