@@ -1,9 +1,8 @@
-from abc import ABC
-from abc import abstractmethod
+from abc import ABC, abstractmethod
+
 
 class Messenger(ABC):
-    """
-    """
+    """ """
 
     @abstractmethod
     def send_message(self, content):
